﻿using System;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.Linq;
using IgOutlook.Infrastructure.Ribbon;
using Microsoft.Practices.Prism.Regions;

namespace IgOutlook.Infrastructure.Prism
{
    public class XamRibbonRegionBehavior : RegionBehavior
    {
        /// <summary>
        /// The key of this behavior.
        /// </summary>
        public const String BehaviorKey = "XamRibbonRegionBehavior";

        protected override void OnAttach()
        {
            this.Region.ActiveViews.CollectionChanged += this.OnActiveViewsChanged;
        }

        void OnActiveViewsChanged(object sender, NotifyCollectionChangedEventArgs e)
        {
            if (e.Action == NotifyCollectionChangedAction.Add)
            {
                Boolean isFirst = true;
                foreach (var newView in e.NewItems)
                {
                    //make sure we are dealing with the right type of view
                    var view = newView as IView;
                    if (view == null)
                        continue;

                    //if we already have ribbons no need on checking again
                    if (view.RibbonTabs.Count > 0)
                        continue;
                    
                    //loop through all the ribbon tab attributes and create them for the view
                    foreach (var atr in GetCustomAttributes<RibbonTabAttribute>(newView.GetType()))
                    {
                        var ribbonTabItem = (IRibbonTabItem)Activator.CreateInstance(atr.Type);
                        ribbonTabItem.ViewModel = view.ViewModel;

                        view.RibbonTabs.Add(ribbonTabItem);
                        ribbonTabItem.IsSelected = isFirst;

                        if (isFirst)
                            isFirst = false;
                    }
                }
            }
        }

        IEnumerable<T> GetCustomAttributes<T>(Type type)
        {
            return type.GetCustomAttributes(typeof(T), true).OfType<T>();
        }
    }
}
