﻿using System;
using IgOutlook.Infrastructure;
using Microsoft.Practices.Prism.Commands;
using Microsoft.Practices.Prism.Events;
using Microsoft.Practices.Prism.Regions;

namespace IgOutlook
{
    public class ShellViewModel : ViewModelBase
    {
        private IRegionManager _regionManager;
        private readonly IEventAggregator _eventAggregator;

        public DelegateCommand<String> NavigateCommand { get; set; }

        public ShellViewModel(IRegionManager regionManager, IEventAggregator eventAggregator)
        {
            _regionManager = regionManager;
            _eventAggregator = eventAggregator;

            NavigateCommand = new DelegateCommand<String>(Navigate);
            Commands.NavigateCommand.RegisterCommand(NavigateCommand);

            _eventAggregator.GetEvent<ViewActivateEvent>().Subscribe(UpdateTitle);
        }

        public void UpdateTitle(string title)
        {
            Title = title;
        }

        private void Navigate(INavigationItem parameter)
        {
            if (parameter == null)
                return;

            string navigatePath = parameter.NavigationPath;

            if (!String.IsNullOrWhiteSpace(navigatePath))
                _regionManager.RequestNavigate(RegionNames.ContentRegion, navigatePath);
        }

        private void Navigate(string navigationPath)
        {
            if (string.IsNullOrWhiteSpace(navigationPath))
                return;

            if (!String.IsNullOrWhiteSpace(navigationPath))
                _regionManager.RequestNavigate(RegionNames.ContentRegion, navigationPath);
        }
    }
}
